/*
 *    SOAPServer.java
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3;

import org.greenstone.gsdl3.core.*;
import org.greenstone.gsdl3.util.GSXML;
import org.w3c.dom.Element;
import java.io.File;
import java.io.BufferedReader;
import java.io.FileReader;
import java.net.URL;

/**
 * The server side of a SOAP connection
 *
 * @author <a href="mailto:kjdon@cs.waikato.ac.nz">Katherine Don</a>
 * @version $Revision: 9735 $
 * @see <a href="http://www.w3.org/TR/SOAP/">Simple Object Access Protocol (SOAP) 1.1 </a>
 */

public class SOAPServerlocalsite
    //implements ModuleInterface {
{
    private String config_file_name = "SOAPServer.cfg";
    
  /** The message router we're talking to */
    MessageRouter mr_=null;
  
  /** The no-args constructor */
    public SOAPServerlocalsite() {
	// find out gsdl3home
	URL url = ClassLoader.getSystemResource(config_file_name);
	if (url == null) {
	    System.err.println("Couldn't find the config file "+config_file_name+". Can't initialise the SOAP server");
	    return;
	}
	String gsdl3_home = readInFile(url);
	if (gsdl3_home == null || gsdl3_home.equals("")) {
	    return;
	}
	String site_home=gsdl3_home+File.separator+"web"+File.separator+"sites"+File.separator+"localsite";
	
	File site_file = new File(site_home);
	if (!site_file.isDirectory()) {
	    System.err.println("The site directory "+site_file.getPath()+" doesn't exist. Can't initialsie the SOAP server.");
	    return;
	}   	
	mr_ = new MessageRouter();
	mr_.setSiteHome(site_home);	
	mr_.configure();
    }
    
    
    /** Process a String request */
//     public String process(String xml_in) {
// 	return mr_.process(xml_in);
	
//     }

//     /** Process an Element request  */
//     public Element process(Element xml_in) {
// 	return mr_.process(xml_in);
//     }

    public Element [] process (Element [] xml_in) {
	Element [] result = new Element[xml_in.length];
	for (int i=0; i<xml_in.length; i++) {
	    Element req = xml_in[i];
	    // get rid of the obligatory namespace that axis needs
	    String tag_name = req.getTagName();
	    String namespace="";
	    if (tag_name.indexOf(':')!= -1) {
		System.err.println("old tag name="+tag_name);
		namespace = tag_name.substring(0, tag_name.indexOf(':'));
		tag_name = tag_name.substring(tag_name.indexOf(':')+1);
		System.err.println("new tag name="+tag_name);
		
	    }
	    Element new_req = GSXML.duplicateWithNewName(req.getOwnerDocument(), req, tag_name, true);
	    Element r = mr_.process(new_req);
	    // add the namespace back on
	    //Element new_res = r;
	    //if (!namespace.equals("")) {
	    //	new_res = GSXML.duplicateWithNewName(r.getOwnerDocument(), r, namespace+r.getTagName(), true);
		//}
	    result[i] = r;
	}
	return result;
    }

    private String readInFile(URL url) {
	String file_name = url.getFile();
	// any spaces are encoded as %20
	file_name = file_name.replaceAll("%20", " ");
	try {
	    BufferedReader reader = new BufferedReader(new FileReader(file_name));
	    String line = reader.readLine();
	    line = line.trim();
	    return line;
	} catch (Exception e) {
	    System.err.println("Exception occurred when reading in the file "+file_name+": "+e);
	}
	return null;
    }

}

